<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:decimal-format name="czech" decimal-separator="," grouping-separator=" "/>

<xsl:template match="/root">
    <html>
    <head>
        <title>DiskSearch print</title>
    <style>
        /* the following definitions must keep their position, they are accessed by its index from javascript */
        .outer{
            width: 121mm;
            height: 121mm;
            overflow: hidden;
            padding: 0pt;
            border:thin dotted black;
        }
        .size{
            color: brown;
        }
        .even{
            background-color: #DDDDDD;
        }
        .folder {
            color: blue;
            background-color: yellow;
        }
        .file{
            color: black;
        }
    /* end */
    .spacing{
            padding: 10pt;
        }
        .type, .name{
            margin-top: 0pt;
            padding-top: 0pt;
            margin-bottom: 0pt;
            padding-bottom: 0pt;
        }
        .type{
            float: right;
        }
        .comment{
            font-style: italic;
        }
        .heading{
            margin-bottom: 1ex;
        }
        .note{
            margin-top: 0pt;
            padding-top: 0pt;
            margin-bottom: 3pt;
            font-size: x-small;
        }
        .list{
            margin-left: 1em;
        }
        .editbox{
            position:absolute;
            right:0px;
            top:0px;
             z-index: 1;
            border: medium solid black;
            margin-left: 1cm;
            margin-bottom: 1cm;
            padding: 10pt;
            display: none;
            background-color: #FAFAD2;
        }

        .withborder{
            border: thin solid black;
            padding: 5pt;
            margin: 5pt;
            background-color: 	#B0C4DE;
        }
    </style>
    <script language="javascript" type='text/javascript' id="functions">
        function showhidediv(id) { //function to hide or show contents of directory
            var mydiv = document.getElementById(id);
            sid = "mark_" + id;
            switchdiv = document.getElementById(sid);
            if (mydiv.style.display == 'none'){ //was hidden
                mydiv.style.display = 'block';
                switchdiv.innerHTML = '-';
            }
            else
            {
                mydiv.style.display = 'none';
                switchdiv.innerHTML = '+';
            }
        }

        function getRules(){ //auxiliary function for display editor
            if (!document.styleSheets) return;
            var theRules = new Array();
            if (document.styleSheets[0].cssRules) // Mozilla
                theRules = document.styleSheets[0].cssRules;
            else if (document.styleSheets[0].rules) // IE
                theRules = document.styleSheets[0].rules;
            return theRules;
        }

        function changeOuterStyle(val){ //change overflow behaviour of the outer div
            var theRules = getRules();
            theRules[0].style.overflow = val;
        }

        function changeOuterSize(){ //change size of the outer div
            var theRules = getRules();
            theRules[0].style.width = document.getElementById('width').value + 'mm';
            theRules[0].style.height = document.getElementById('height').value + 'mm';
        }

        function changeColours(){ //change colours of various elements
            var theRules = getRules();
            if (document.getElementById('filesize').value){
                theRules[1].style.color = document.getElementById('filesize').value;
            }
            if (document.getElementById('evenline').value){
                theRules[2].style.backgroundColor = document.getElementById('evenline').value;
            }
            if (document.getElementById('foldername').value){
                theRules[3].style.color = document.getElementById('foldername').value;
            }
            if (document.getElementById('foldernameback').value){
                theRules[3].style.backgroundColor = document.getElementById('foldernameback').value;
            }
            if (document.getElementById('filename').value){
                theRules[4].style.color = document.getElementById('filename').value;
            }
        }

        function changeLabels(){ //change labels
            if (document.getElementById('disclabel').value){
                document.getElementById('name').innerHTML = document.getElementById('disclabel').value;
            }
            if (document.getElementById('disctype').value){
                document.getElementById('type').innerHTML = document.getElementById('disctype').value;
            }
            if (document.getElementById('disccomment').value){
                document.getElementById('comment').innerHTML = document.getElementById('disccomment').value;
            }
        }

        function fillDefaults(what){ // fill sizes of common used boxes
            if (what == 'cd'){
                document.getElementById('width').value = 121;
                document.getElementById('height').value = 121;
            }
            else if (what == 'dvd'){
                document.getElementById('width').value = 130;
                document.getElementById('height').value = 184;
            }
            else if (what == 'dvda'){
                document.getElementById('width').value = 273;
                document.getElementById('height').value = 184;
            }
        }

        function swap(){ // swap width and height
            oldwidth = document.getElementById('width').value;
            document.getElementById('width').value = document.getElementById('height').value;
            document.getElementById('height').value = oldwidth;
        }
    </script>
    </head>
    <body>
            <button type="button" onclick="document.getElementById('editbox').style.display = 'block';">Show layout editor</button>
            <button type="button" onclick="document.getElementById('editbox').style.display = 'none';">Hide layout editor</button>
            <br/><br/>
            <div class="editbox" id="editbox">
                <h3>Edit display properties:</h3>
                <div class="withborder">
                        <p><b>What to do if the content is larger than the size of the frame</b></p>
                        <p>The buttons change CSS property of the outer (dotted) frame</p>
                        <p>
                            <form>
                                <button type="button" onclick="javascript:changeOuterStyle('visible')">Visible</button>
                                <button type="button" onclick="javascript:changeOuterStyle('hidden')"><b>Hidden</b></button>
                                <button type="button" onclick="javascript:changeOuterStyle('scroll')">Scroll</button>
                                <button type="button" onclick="javascript:changeOuterStyle('auto')">Auto</button>
                            </form>
                        </p>
                </div>
                <div class="withborder">
                    <p><b>Change size of the frame</b></p>
                    <p>Enter values in milimeters or use predefined values: </p>
                        <form>
                            <button type="button" onclick="javascript:fillDefaults('cd')"><b>CD</b></button>
                            <button type="button" onclick="javascript:fillDefaults('dvd')">DVD (front)</button>
                            <button type="button" onclick="javascript:fillDefaults('dvda')">DVD (whole)</button>
                        </form>
                    <p>
                        <form>
                            width: <input type="text" id="width" size="10"/>
                            <button type="button" onclick="javascript:swap()">swap &lt; - &gt;</button>
                            height: <input type="text" id="height" size="10"/> (mm)
                            <p>
                                <button type="button" onclick="javascript:changeOuterSize()"><b>Apply</b></button>
                            </p>
                        </form>
                    </p>
                </div>
                <div class="withborder">
                    <p><b>Colours</b></p>
                        <p>Enter valid CSS color</p>
                        <form>
                            <table>
                            <tr><th>Element</th><th>Color</th></tr>
                            <tr><td>file name: </td><td><input type="text" id="filename" size="10"/></td></tr>
                            <tr><td>file size: </td><td><input type="text" id="filesize" size="10"/></td></tr>
                            <tr><td>even line background: </td><td><input type="text" id="evenline" size="10"/></td></tr>
                            <tr><td>folder name: </td><td><input type="text" id="foldername" size="10"/></td></tr>
                            <tr><td>folder name background: </td><td><input type="text" id="foldernameback" size="10"/></td></tr>
                            </table>
                        </form>
                        <button type="button" onclick="javascript:changeColours()"><b>Apply</b></button>
                </div>
                <div class="withborder">
                    <p><b>Labels</b></p>
                        <form>
                            <table>
                            <tr><th>Element</th><th>Label</th></tr>
                            <tr><td>disc label: </td><td><input type="text" id="disclabel" size="10"/></td></tr>
                            <tr><td>disc type: </td><td><input type="text" id="disctype" size="10"/></td></tr>
                            <tr><td>disc comment: </td><td><input type="text" id="disccomment" size="10"/></td></tr>
                            </table>
                        </form>
                        <button type="button" onclick="javascript:changeLabels()"><b>Apply</b></button>
                </div>
            </div>
        <div class="outer">
	  <div class="spacing">
            <div class="note">
                Printed by DiskSearch.
            </div>
            <div class="heading">
                <h1 class="type" id="type"><xsl:value-of select="@type"/></h1>
                <h2 class="name" id="name"><xsl:value-of select="@name"/></h2>
                <br style="clear: both;"/>
                <div class="comment" id="comment"><xsl:value-of select="@comment"/></div>
            </div>
            <div>
                <xsl:call-template name="process"/>
            </div>
          </div>
        </div>
    </body>
    </html>
</xsl:template>

<xsl:template name="process">
    <xsl:apply-templates select="folder">
        <xsl:sort select="path"/>
    </xsl:apply-templates>
    <xsl:for-each select="file">
        <div>
            <xsl:if test="position() mod 2 = 0">
                <xsl:attribute name="class">even</xsl:attribute>
            </xsl:if>
            <xsl:call-template name="file"/>
        </div>
    </xsl:for-each>
</xsl:template>


<!-- process the individual files
  in the space-separated file list -->
<xsl:template name="file">
    <div>
	<div style="float: right">
            <xsl:if test="number(@size) =number(@size)">
		<!-- the value is number, not general string -->
        	<span class="size"><xsl:value-of select="format-number(@size, '# ### ### ###','czech')"/></span>
	    </xsl:if>
	</div>
        <span class="file"><xsl:value-of select="@path"/></span>
    </div>
</xsl:template>

<xsl:template match="folder">
    <div>
        <a class="folder" title="Click to show/hide">
                <xsl:attribute name="id">switcher_<xsl:value-of select="@id"/></xsl:attribute>
                <xsl:attribute name="href">javascript:showhidediv('<xsl:value-of select="@id"/>');</xsl:attribute>
                [<span>
                <xsl:attribute name="id">mark_<xsl:value-of select="@id"/></xsl:attribute>
                -</span>]
            <xsl:value-of select="@path"/>
        </a>
	<xsl:if test="@note">(<xsl:value-of select="@note"/>)</xsl:if>
        <div>
            <xsl:attribute name="class">list</xsl:attribute>
            <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
            <xsl:call-template name="process"/>
        </div>
    </div>
</xsl:template>

</xsl:stylesheet>
